@@ -28,6 +28,9 @@
 
 #include <language/interfaces/iastcontainer.h>
 
+#include <QMutexLocker>
+#include <QRecursiveMutex>
+
 // #define DEBUG_SEARCH
 
 const uint maxApplyAliasesRecursion = 100;
@@ -77,7 +80,7 @@ DEFINE_LIST_MEMBER_HASH(TopDUContextData, m_usedDeclarationIds, DeclarationId)
 DEFINE_LIST_MEMBER_HASH(TopDUContextData, m_problems, LocalIndexedProblem)
 REGISTER_DUCHAIN_ITEM(TopDUContext);
 
-QMutex importStructureMutex(QMutex::Recursive);
+QRecursiveMutex importStructureMutex;
 
 //Contains data that is not shared among top-contexts that share their duchain entries
 class TopDUContextLocalPrivate
