@@ -1,22 +1,10 @@
-/* This file is part of KDevelop
-    Copyright 2006 Roberto Raggi <roberto@kdevelop.org>
-    Copyright 2006-2008 Hamish Rodda <rodda@kde.org>
-    Copyright 2007-2008 David Nolden <david.nolden.kdevelop@art-master.de>
+/*
+    SPDX-FileCopyrightText: 2006 Roberto Raggi <roberto@kdevelop.org>
+    SPDX-FileCopyrightText: 2006-2008 Hamish Rodda <rodda@kde.org>
+    SPDX-FileCopyrightText: 2007-2008 David Nolden <david.nolden.kdevelop@art-master.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
- */
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #include "abstracttype.h"
 
@@ -56,6 +44,38 @@ void AbstractType::setModifiers(quint32 modifiers)
     d_func_dynamic()->m_modifiers = modifiers;
 }
 
+int64_t AbstractType::sizeOf() const
+{
+    return d_func()->m_sizeOf;
+}
+
+void AbstractType::setSizeOf(int64_t sizeOf)
+{
+    d_func_dynamic()->m_sizeOf = sizeOf;
+}
+
+int64_t AbstractType::alignOf() const
+{
+    if (d_func()->m_alignOfExponent == AbstractTypeData::MaxAlignOfExponent) {
+        return -1;
+    } else {
+        return Q_INT64_C(1) << d_func()->m_alignOfExponent;
+    }
+}
+
+void AbstractType::setAlignOf(int64_t alignedTo)
+{
+    if (alignedTo <= 0) {
+        d_func_dynamic()->m_alignOfExponent = AbstractTypeData::MaxAlignOfExponent;
+        return;
+    }
+
+    unsigned int alignOfExponent = 0;
+    while (alignedTo >>= 1)
+        alignOfExponent++;
+    d_func_dynamic()->m_alignOfExponent = alignOfExponent;
+}
+
 AbstractType::AbstractType()
     : d_ptr(&createData<AbstractType>())
 {
@@ -102,12 +122,15 @@ IndexedType AbstractType::indexed() const
 bool AbstractType::equals(const AbstractType* rhs) const
 {
     //qCDebug(LANGUAGE) << this << rhs << modifiers() << rhs->modifiers();
-    return d_func()->typeClassId == rhs->d_func()->typeClassId && modifiers() == rhs->modifiers();
+    return d_func()->typeClassId == rhs->d_func()->typeClassId && d_func()->m_modifiers == rhs->d_func()->m_modifiers
+        && d_func()->m_sizeOf == rhs->d_func()->m_sizeOf
+        && d_func()->m_alignOfExponent == rhs->d_func()->m_alignOfExponent;
 }
 
 uint AbstractType::hash() const
 {
-    return KDevHash() << d_func()->typeClassId << d_func()->m_modifiers;
+    return KDevHash() << d_func()->typeClassId << d_func()->m_modifiers << d_func()->m_sizeOf
+                      << d_func()->m_alignOfExponent;
 }
 
 QString AbstractType::toString() const
