@@ -1,23 +1,8 @@
 /*
-* KDevelop C++ Language Support
-*
-* Copyright 2007 David Nolden <david.nolden.kdevelop@art-master.de>
-* Copyright 2014 Kevin Funk <kfunk@kde.org>
-*
-* This program is free software; you can redistribute it and/or modify
-* it under the terms of the GNU Library General Public License as
-* published by the Free Software Foundation; either version 2 of the
-* License, or (at your option) any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public
-* License along with this program; if not, write to the
-* Free Software Foundation, Inc.,
-* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    SPDX-FileCopyrightText: 2007 David Nolden <david.nolden.kdevelop@art-master.de>
+    SPDX-FileCopyrightText: 2014 Kevin Funk <kfunk@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "makefileresolver.h"
@@ -30,6 +15,8 @@
 
 #include <QDir>
 #include <QFileInfo>
+#include <QMutex>
+#include <QMutexLocker>
 #include <QRegularExpression>
 #include <QRegExp>
 
@@ -316,17 +303,19 @@ PathResolutionResult MakeFileResolver::resolveIncludePath(const QString& file, c
           return ret;
         } else {
           //We have a cached failed result. We should use that for some time but then try again. Return the failed result if: (there were too many tries within this folder OR this file was already tried) AND The last tries have not expired yet
-          if (/*(it->failedFiles.size() > 3 || it->failedFiles.find(file) != it->failedFiles.end()) &&*/ it->failTime.secsTo(QDateTime::currentDateTime()) < CACHE_FAIL_FOR_SECONDS) {
-            PathResolutionResult ret(false); //Fake that the result is ok
-            ret.errorMessage = i18n("Cached: %1", it->errorMessage);
-            ret.longErrorMessage = it->longErrorMessage;
-            ret.paths = it->paths;
-            ret.frameworkDirectories = it->frameworkDirectories;
-            ret.defines = it->defines;
-            ret.mergeWith(resultOnFail);
-            return ret;
+          if (/*(it->failedFiles.size() > 3 || it->failedFiles.find(file) != it->failedFiles.end()) &&*/ it->failTime
+                  .secsTo(QDateTime::currentDateTimeUtc())
+              < CACHE_FAIL_FOR_SECONDS) {
+              PathResolutionResult ret(false); // Fake that the result is ok
+              ret.errorMessage = i18n("Cached: %1", it->errorMessage);
+              ret.longErrorMessage = it->longErrorMessage;
+              ret.paths = it->paths;
+              ret.frameworkDirectories = it->frameworkDirectories;
+              ret.defines = it->defines;
+              ret.mergeWith(resultOnFail);
+              return ret;
           } else {
-            //Try getting a correct result again
+              // Try getting a correct result again
           }
         }
       }
@@ -398,7 +387,7 @@ PathResolutionResult MakeFileResolver::resolveIncludePath(const QString& file, c
       ce.failed = true;
       ce.errorMessage = res.errorMessage;
       ce.longErrorMessage = res.longErrorMessage;
-      ce.failTime = QDateTime::currentDateTime();
+      ce.failTime = QDateTime::currentDateTimeUtc();
       ce.failedFiles[file] = true;
     } else {
       ce.failed = false;
