@@ -1,34 +1,27 @@
 /*
- * Copyright <year> Milian Wolff <mail@milianw.de>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: Milian Wolff <mail@milianw.de>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "test_quickopen.h"
 #include <interfaces/idocumentcontroller.h>
+#include <project/projectutils.h>
 
 #include <QTemporaryDir>
 #include <QTest>
 #include <QTemporaryFile>
 
+#include <type_traits>
+#include <utility>
+
 QTEST_MAIN(TestQuickOpen)
 
 using namespace KDevelop;
 
+static_assert(std::is_nothrow_move_assignable<ProjectFile>(), "Why would a move assignment operator throw?");
+static_assert(std::is_nothrow_move_constructible<ProjectFile>(), "Why would a move constructor throw?");
+
 using ItemList = QVector<DUChainItem>;
 using StringList = QVector<QString>;
 
@@ -36,6 +29,54 @@ using StringList = QVector<QString>;
 TestQuickOpen::TestQuickOpen(QObject* parent)
     : QuickOpenTestBase(Core::Default, parent)
 {
+    QStandardPaths::setTestModeEnabled(true);
+}
+
+void TestQuickOpen::testProjectFileSwap()
+{
+    QScopedPointer<TestProject> project(getProjectWithFiles(2));
+    QVector<ProjectFile> projectFiles;
+    KDevelop::forEachFile(project->projectItem(), [&projectFiles](ProjectFileItem* fileItem) {
+        projectFiles.push_back(ProjectFile{fileItem});
+    });
+    QCOMPARE(projectFiles.size(), 2);
+
+    const auto equivalent = [](const ProjectFile &x, const ProjectFile &y) {
+        return !(x < y) && !(y < x);
+    };
+
+    ProjectFile a = projectFiles.at(0);
+    ProjectFile b = projectFiles.at(1);
+    QCOMPARE(a.projectPath, b.projectPath);
+    QVERIFY(!equivalent(a, b));
+
+    const auto aCopy = a;
+    const auto bCopy = b;
+    QCOMPARE(aCopy.projectPath, a.projectPath);
+    QVERIFY(equivalent(aCopy, a));
+    QCOMPARE(bCopy.projectPath, b.projectPath);
+    QVERIFY(equivalent(bCopy, b));
+
+    using std::swap;
+
+    swap(a, b);
+    QCOMPARE(a.projectPath, bCopy.projectPath);
+    QVERIFY(equivalent(a, bCopy));
+    QCOMPARE(b.projectPath, aCopy.projectPath);
+    QVERIFY(equivalent(b, aCopy));
+
+    const QString anotherProjectPath = QStringLiteral("/some/special/path/to/a-project");
+    a.projectPath = Path{anotherProjectPath};
+    QCOMPARE(a.projectPath.pathOrUrl(), anotherProjectPath);
+
+    swap(a, b);
+    QCOMPARE(a.projectPath, aCopy.projectPath);
+    QVERIFY(equivalent(a, aCopy));
+    QCOMPARE(b.projectPath.pathOrUrl(), anotherProjectPath);
+    QVERIFY(equivalent(b, bCopy));
+
+    QVERIFY(a.projectPath != b.projectPath);
+    QVERIFY(!equivalent(a, b));
 }
 
 void TestQuickOpen::testDuchainFilter()
@@ -97,7 +138,7 @@ void TestQuickOpen::testAbbreviations()
     QFETCH(StringList, filtered);
 
     PathTestFilter filterItems;
-    filterItems.setItems(items);
+    filterItems.setItems(std::move(items));
 #if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
     filterItems.setFilter(filter.split('/', Qt::SkipEmptyParts));
 #else
@@ -135,7 +176,7 @@ void TestQuickOpen::testSorting()
     const auto filterList = filter.split('/', QString::SkipEmptyParts);
 #endif
     PathTestFilter filterItems;
-    filterItems.setItems(items);
+    filterItems.setItems(std::move(items));
     filterItems.setFilter(filterList);
     QEXPECT_FAIL("bar7", "empty parts are skipped", Abort);
     if (filterItems.filteredItems() != filtered)
